@@ -162,10 +162,11 @@ textmodel_wordmap.dfm <- function(x, y, label = c("all", "max"), smooth = 0.01,
             v1 <- s + smooth
         } else {
             if (smooth >= 1.0)
-                warning("The value of smooth became fractional in wordmap v0.92")
+                warning("The value of smooth became fractional in wordmap v0.9.2")
             a <- mean(s)
-            v0 <- m - s + (a * smooth)
-            v1 <- s + (a * smooth)
+            e <- .Machine$double.eps
+            v0 <- m - s + (a * smooth) + e
+            v1 <- s + (a * smooth) + e
         }
         model[key,] <- log(v1 / sum(v1)) - log(v0 / sum(v0)) # log-likelihood ratio
 
